<?php

namespace Litecms\CouponOffer\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\CouponOffer\Models\CouponOffer;

class CouponOfferPolicy
{

    /**
     * Determine if the given user can view the coupon__offer.
     *
     * @param UserPolicy $user
     * @param CouponOffer $coupon__offer
     *
     * @return bool
     */
    public function view(UserPolicy $user, CouponOffer $coupon__offer)
    {
        if ($user->canDo('coupon__offer.coupon__offer.view') && $user->isAdmin()) {
            return true;
        }

        return $coupon__offer->user_id == user_id() && $coupon__offer->user_type == user_type();
    }

    /**
     * Determine if the given user can create a coupon__offer.
     *
     * @param UserPolicy $user
     * @param CouponOffer $coupon__offer
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('coupon__offer.coupon__offer.create');
    }

    /**
     * Determine if the given user can update the given coupon__offer.
     *
     * @param UserPolicy $user
     * @param CouponOffer $coupon__offer
     *
     * @return bool
     */
    public function update(UserPolicy $user, CouponOffer $coupon__offer)
    {
        if ($user->canDo('coupon__offer.coupon__offer.edit') && $user->isAdmin()) {
            return true;
        }

        return $coupon__offer->user_id == user_id() && $coupon__offer->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given coupon__offer.
     *
     * @param UserPolicy $user
     * @param CouponOffer $coupon__offer
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, CouponOffer $coupon__offer)
    {
        return $coupon__offer->user_id == user_id() && $coupon__offer->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given coupon__offer.
     *
     * @param UserPolicy $user
     * @param CouponOffer $coupon__offer
     *
     * @return bool
     */
    public function verify(UserPolicy $user, CouponOffer $coupon__offer)
    {
        if ($user->canDo('coupon__offer.coupon__offer.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given coupon__offer.
     *
     * @param UserPolicy $user
     * @param CouponOffer $coupon__offer
     *
     * @return bool
     */
    public function approve(UserPolicy $user, CouponOffer $coupon__offer)
    {
        if ($user->canDo('coupon__offer.coupon__offer.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
