<?php

namespace Litecms\CouponOffer\Providers;

use Illuminate\Support\ServiceProvider;

class CouponOfferServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'coupon__offer');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'coupon__offer');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('litecms.coupon__offer', function ($app) {
            return $this->app->make('Litecms\CouponOffer\CouponOffer');
        });

                // Bind CouponOffer to repository
        $this->app->bind(
            'Litecms\CouponOffer\Interfaces\CouponOfferRepositoryInterface',
            \Litecms\CouponOffer\Repositories\Eloquent\CouponOfferRepository::class
        );

        $this->app->register(\Litecms\CouponOffer\Providers\AuthServiceProvider::class);
                $this->app->register(\Litecms\CouponOffer\Providers\EventServiceProvider::class);
        
        $this->app->register(\Litecms\CouponOffer\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.coupon__offer'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/coupon__offer.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/coupon__offer')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/coupon__offer')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
